Module: Swgr2rb::Boolean
- Included in:
- FalseClass, TrueClass
- Defined in:
- lib/prototypes/json_schema_data_types.rb
Overview
Boolean module is included in TrueClass and FalseClass so that it can be used as a type when dealing with JSON schemas
Boolean module is included in TrueClass and FalseClass so that it can be used as a type when dealing with JSON schemas